@@ -1,4 +1,4 @@
-/* Copyright (c) 2008, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2008, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
@@ -122,6 +122,11 @@ TABLE_FIELD_DEF
 table_threads::m_field_def=
 { 17, field_types };
 
+PFS_engine_table_share_state
+table_threads::m_share_state = {
+  false /* m_checked */
+};
+
 PFS_engine_table_share
 table_threads::m_share=
 {
@@ -134,8 +139,9 @@ table_threads::m_share=
   sizeof(PFS_simple_index), /* ref length */
   &m_table_lock,
   &m_field_def,
-  false, /* checked */
-  false  /* perpetual */
+  false, /* m_perpetual */
+  false, /* m_optional */
+  &m_share_state
 };
 
 PFS_engine_table* table_threads::create()
